==> ec2-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/Peer.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Factories for static connection peer.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:23:14.074Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.Peer")
public class Peer extends software.amazon.jsii.JsiiObject {

    protected Peer(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Peer(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Peer() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this));
    }

    /**
     * Any IPv4 address.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IPeer anyIpv4() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Peer.class, "anyIpv4", software.amazon.awscdk.services.ec2.IPeer.class);
    }

    /**
     * Any IPv6 address.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IPeer anyIpv6() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Peer.class, "anyIpv6", software.amazon.awscdk.services.ec2.IPeer.class);
    }

    /**
     * Create an IPv4 peer from a CIDR.
     * 
     * @param cidrIp This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IPeer ipv4(final java.lang.String cidrIp) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Peer.class, "ipv4", software.amazon.awscdk.services.ec2.IPeer.class, new Object[] { java.util.Objects.requireNonNull(cidrIp, "cidrIp is required") });
    }

    /**
     * Create an IPv6 peer from a CIDR.
     * 
     * @param cidrIp This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IPeer ipv6(final java.lang.String cidrIp) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Peer.class, "ipv6", software.amazon.awscdk.services.ec2.IPeer.class, new Object[] { java.util.Objects.requireNonNull(cidrIp, "cidrIp is required") });
    }

    /**
     * A prefix list.
     * 
     * @param prefixListId This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IPeer prefixList(final java.lang.String prefixListId) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Peer.class, "prefixList", software.amazon.awscdk.services.ec2.IPeer.class, new Object[] { java.util.Objects.requireNonNull(prefixListId, "prefixListId is required") });
    }
}

==> ec2-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/Peer.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Factories for static connection peer.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:50.815Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.Peer")
public class Peer extends software.amazon.jsii.JsiiObject {

    protected Peer(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Peer(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Peer() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Any IPv4 address.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IPeer anyIpv4() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Peer.class, "anyIpv4", software.amazon.awscdk.services.ec2.IPeer.class);
    }

    /**
     * Any IPv6 address.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IPeer anyIpv6() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Peer.class, "anyIpv6", software.amazon.awscdk.services.ec2.IPeer.class);
    }

    /**
     * Create an IPv4 peer from a CIDR.
     * 
     * @param cidrIp This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IPeer ipv4(final java.lang.String cidrIp) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Peer.class, "ipv4", software.amazon.awscdk.services.ec2.IPeer.class, new Object[] { java.util.Objects.requireNonNull(cidrIp, "cidrIp is required") });
    }

    /**
     * Create an IPv6 peer from a CIDR.
     * 
     * @param cidrIp This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IPeer ipv6(final java.lang.String cidrIp) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Peer.class, "ipv6", software.amazon.awscdk.services.ec2.IPeer.class, new Object[] { java.util.Objects.requireNonNull(cidrIp, "cidrIp is required") });
    }

    /**
     * A prefix list.
     * 
     * @param prefixListId This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IPeer prefixList(final java.lang.String prefixListId) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Peer.class, "prefixList", software.amazon.awscdk.services.ec2.IPeer.class, new Object[] { java.util.Objects.requireNonNull(prefixListId, "prefixListId is required") });
    }
}
